# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/task_step.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import task_stereotype_pb2 as avikom_dot_assistance_dot_task__stereotype__pb2
from avikom.assistance import instruction_text_pb2 as avikom_dot_assistance_dot_instruction__text__pb2
from avikom.assistance import instruction_media_pb2 as avikom_dot_assistance_dot_instruction__media__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/assistance/task_step.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\'avikom/assistance/task_stereotype.proto\x1a(avikom/assistance/instruction_text.proto\x1a)avikom/assistance/instruction_media.proto\"\xc5\x01\n\x08TaskStep\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12/\n\x04type\x18\x03 \x01(\x0b\x32!.avikom.assistance.TaskStereotype\x12\x38\n\x0cinstructions\x18\x04 \x03(\x0b\x32\".avikom.assistance.InstructionText\x12\x32\n\x05media\x18\x05 \x03(\x0b\x32#.avikom.assistance.InstructionMedia:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.task_step_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _TASKSTEP.fields_by_name['name']._options = None
  _TASKSTEP.fields_by_name['name']._serialized_options = b'\212\265\030\002\020\001'
  _TASKSTEP._options = None
  _TASKSTEP._serialized_options = b'\210\265\030\001'
  _TASKSTEP._serialized_start=213
  _TASKSTEP._serialized_end=410
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/peer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.generic import rpc_endpoint_pb2 as avikom_dot_generic_dot_rpc__endpoint__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.generic import modality_pb2 as avikom_dot_generic_dot_modality__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61vikom/generic/peer.proto\x12\x0e\x61vikom.generic\x1a\x1c\x61vikom/options/options.proto\x1a!avikom/generic/rpc_endpoint.proto\x1a\x19\x61vikom/generic/user.proto\x1a\x1d\x61vikom/generic/modality.proto\"\xf7\x01\n\x04Peer\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\thost_name\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\"\n\x04user\x18\x06 \x01(\x0b\x32\x14.avikom.generic.User\x12/\n\rmodal_fitness\x18\x07 \x01(\x0b\x32\x18.avikom.generic.Modality\x12\x0f\n\x07gateway\x18\x08 \x01(\t\x12\x10\n\x08services\x18\n \x03(\t\x12.\n\tendpoints\x18\x0b \x03(\x0e\x32\x1b.avikom.generic.RpcEndpoint:\x04\x88\xb5\x18\x01\"/\n\x08PeerList\x12#\n\x05peers\x18\x01 \x03(\x0b\x32\x14.avikom.generic.PeerBl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.peer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _PEER.fields_by_name['name']._options = None
  _PEER.fields_by_name['name']._serialized_options = b'\212\265\030\002\020\001'
  _PEER._options = None
  _PEER._serialized_options = b'\210\265\030\001'
  _PEER._serialized_start=169
  _PEER._serialized_end=416
  _PEERLIST._serialized_start=418
  _PEERLIST._serialized_end=465
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.headset import audio_peer_control_service_pb2 as avikom_dot_headset_dot_audio__peer__control__service__pb2


class AudioPeerControlServiceStub(object):
    """*
    This service controls an auditory peer. It can be used to trigger sounds, speech output or change 
    the mode of the auditory peer.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetMode = channel.unary_unary(
                '/avikom.headset.AudioPeerControlService/SetMode',
                request_serializer=avikom_dot_headset_dot_audio__peer__control__service__pb2.AudioPeerModeRequest.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.PlaySound = channel.unary_unary(
                '/avikom.headset.AudioPeerControlService/PlaySound',
                request_serializer=avikom_dot_headset_dot_audio__peer__control__service__pb2.FunctionalSoundRequest.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.Say = channel.unary_unary(
                '/avikom.headset.AudioPeerControlService/Say',
                request_serializer=avikom_dot_headset_dot_audio__peer__control__service__pb2.SayRequest.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class AudioPeerControlServiceServicer(object):
    """*
    This service controls an auditory peer. It can be used to trigger sounds, speech output or change 
    the mode of the auditory peer.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    def SetMode(self, request, context):
        """/ sets the mode of the auditory peer. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlaySound(self, request, context):
        """/ triggers immediate playback of a sound. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Say(self, request, context):
        """/ triggers generation of TTS output and playback on the auditory peer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AudioPeerControlServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetMode': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMode,
                    request_deserializer=avikom_dot_headset_dot_audio__peer__control__service__pb2.AudioPeerModeRequest.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'PlaySound': grpc.unary_unary_rpc_method_handler(
                    servicer.PlaySound,
                    request_deserializer=avikom_dot_headset_dot_audio__peer__control__service__pb2.FunctionalSoundRequest.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'Say': grpc.unary_unary_rpc_method_handler(
                    servicer.Say,
                    request_deserializer=avikom_dot_headset_dot_audio__peer__control__service__pb2.SayRequest.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.headset.AudioPeerControlService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AudioPeerControlService(object):
    """*
    This service controls an auditory peer. It can be used to trigger sounds, speech output or change 
    the mode of the auditory peer.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    @staticmethod
    def SetMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.headset.AudioPeerControlService/SetMode',
            avikom_dot_headset_dot_audio__peer__control__service__pb2.AudioPeerModeRequest.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlaySound(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.headset.AudioPeerControlService/PlaySound',
            avikom_dot_headset_dot_audio__peer__control__service__pb2.FunctionalSoundRequest.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Say(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.headset.AudioPeerControlService/Say',
            avikom_dot_headset_dot_audio__peer__control__service__pb2.SayRequest.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/options/options.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61vikom/options/options.proto\x12\x0e\x61vikom.options\x1a google/protobuf/descriptor.proto\"\x81\x01\n\x0c\x46ieldOptions\x12\r\n\x05index\x18\x01 \x01(\x08\x12\x0e\n\x06unique\x18\x02 \x01(\x08\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x03 \x01(\t\x12\r\n\x05match\x18\x04 \x01(\t\x12\x0b\n\x03min\x18\x05 \x01(\t\x12\x11\n\timmutable\x18\x06 \x01(\x08\x12\x12\n\nauto_index\x18\x07 \x01(\x08:M\n\x06schema\x12\x1d.google.protobuf.FieldOptions\x18\xd1\x86\x03 \x01(\x0b\x32\x1c.avikom.options.FieldOptions:<\n\x11schema_definition\x12\x1f.google.protobuf.MessageOptions\x18\xd1\x86\x03 \x01(\x08\x42l\n\x18\x61pp.avikom.types.optionsZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/options\xaa\x02\x14\x41vikom.Types.Optionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.options.options_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(schema)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(schema_definition)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.optionsZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/options\252\002\024Avikom.Types.Options'
  _FIELDOPTIONS._serialized_start=83
  _FIELDOPTIONS._serialized_end=212
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AnswerQuestionQuery(google.protobuf.message.Message):
    """*
    This message is used to ask a question to be answered on the basis of the context.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTEXT_FIELD_NUMBER: builtins.int
    QUESTION_FIELD_NUMBER: builtins.int
    context: builtins.str
    """/ this text string should contain the answer to the question"""
    question: builtins.str
    """/ the question you would like to find an answer to in the context"""
    def __init__(
        self,
        *,
        context: builtins.str = ...,
        question: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "question", b"question"]) -> None: ...

global___AnswerQuestionQuery = AnswerQuestionQuery

@typing_extensions.final
class AnswerQuestionResponse(google.protobuf.message.Message):
    """*
    This message is includes the response to the posed question and where in the context the answer was found.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    ANSWER_FIELD_NUMBER: builtins.int
    score: builtins.float
    """/ confidence between 0-1 that the correct answer was found"""
    start: builtins.int
    """/ start position of answer in charactercount"""
    end: builtins.int
    """/ end position of answer in charactercount"""
    answer: builtins.str
    """/ the answer to the posed question is a text excerpt from the context"""
    def __init__(
        self,
        *,
        score: builtins.float = ...,
        start: builtins.int = ...,
        end: builtins.int = ...,
        answer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["answer", b"answer", "end", b"end", "score", b"score", "start", b"start"]) -> None: ...

global___AnswerQuestionResponse = AnswerQuestionResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.task_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Scene(google.protobuf.message.Message):
    """*
    Describes the location/context of a task. This might be an office or a lab.
    The `tasks` field should only contain tasks that can be intialized without further information.
    For instance, when a task requires to be prepened by another task, it should be mentioned here.
    Thus, an `Issue` might contain a task that is not mentioned in `Session.tasks`.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ a unique name for the location/context"""
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.task_pb2.Task]:
        """all the tasks that can be conducted without further information"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tasks: collections.abc.Iterable[avikom.assistance.task_pb2.Task] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "tasks", b"tasks"]) -> None: ...

global___Scene = Scene



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.generic.content_type_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MediaInfo(google.protobuf.message.Message):
    """*
    This message describes a media file, it's name (or file path), its content type (e.g. video, audio, image) and the current playback time if applicable.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIA_NAME_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    MILLISECONDS_FIELD_NUMBER: builtins.int
    media_name: builtins.str
    """/ media name, identifier or file path"""
    content_type: avikom.generic.content_type_pb2.ContentType.ValueType
    """/ the content type, e.g. video, image or audio"""
    milliseconds: builtins.int
    """/ the current playback time location; not applicable for images etc."""
    def __init__(
        self,
        *,
        media_name: builtins.str = ...,
        content_type: avikom.generic.content_type_pb2.ContentType.ValueType = ...,
        milliseconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "media_name", b"media_name", "milliseconds", b"milliseconds"]) -> None: ...

global___MediaInfo = MediaInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/math/float_matrix.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.math import float_array_pb2 as avikom_dot_math_dot_float__array__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61vikom/math/float_matrix.proto\x12\x0b\x61vikom.math\x1a\x1d\x61vikom/math/float_array.proto\"4\n\x0b\x46loatMatrix\x12%\n\x04rows\x18\x01 \x03(\x0b\x32\x17.avikom.math.FloatArrayBc\n\x15\x61pp.avikom.types.mathZ6gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/math\xaa\x02\x11\x41vikom.Types.Mathb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.math.float_matrix_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025app.avikom.types.mathZ6gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/math\252\002\021Avikom.Types.Math'
  _FLOATMATRIX._serialized_start=78
  _FLOATMATRIX._serialized_end=130
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/key_value_pair.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#avikom/generic/key_value_pair.proto\x12\x0e\x61vikom.generic\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tBl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.key_value_pair_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _KEYVALUEPAIR._serialized_start=55
  _KEYVALUEPAIR._serialized_end=97
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/asset_bundle_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.unity import asset_bundle_pb2 as avikom_dot_unity_dot_asset__bundle__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'avikom/unity/asset_bundle_service.proto\x12\x0c\x61vikom.unity\x1a\x1f\x61vikom/unity/asset_bundle.proto\x1a\x1cgoogle/api/annotations.proto\"\'\n\x10\x41ssetBundleQuery\x12\x13\n\x0b\x62undle_name\x18\x01 \x01(\t2Z\n\x12\x41ssetBundleService\x12\x44\n\x03Get\x12\x1e.avikom.unity.AssetBundleQuery\x1a\x19.avikom.unity.AssetBundle\"\x00\x30\x01\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.asset_bundle_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _ASSETBUNDLEQUERY._serialized_start=120
  _ASSETBUNDLEQUERY._serialized_end=159
  _ASSETBUNDLESERVICE._serialized_start=161
  _ASSETBUNDLESERVICE._serialized_end=251
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/scene_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from avikom.unity import waypoint_pb2 as avikom_dot_unity_dot_waypoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61vikom/unity/scene_config.proto\x12\x0c\x61vikom.unity\x1a\x1c\x61vikom/options/options.proto\x1a\x1e\x61vikom/unity/game_object.proto\x1a\x1b\x61vikom/unity/waypoint.proto\"\xaf\x01\n\x0bSceneConfig\x12\x1a\n\nscene_name\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12)\n\x07\x61nchors\x18\x02 \x03(\x0b\x32\x18.avikom.unity.GameObject\x12(\n\x06\x61ssets\x18\x03 \x03(\x0b\x32\x18.avikom.unity.GameObject\x12)\n\twaypoints\x18\x04 \x03(\x0b\x32\x16.avikom.unity.Waypoint:\x04\x88\xb5\x18\x01\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.scene_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _SCENECONFIG.fields_by_name['scene_name']._options = None
  _SCENECONFIG.fields_by_name['scene_name']._serialized_options = b'\212\265\030\002\020\001'
  _SCENECONFIG._options = None
  _SCENECONFIG._serialized_options = b'\210\265\030\001'
  _SCENECONFIG._serialized_start=141
  _SCENECONFIG._serialized_end=316
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.headset import rasa_message_pb2 as avikom_dot_headset_dot_rasa__message__pb2
from avikom.headset import rasa_service_pb2 as avikom_dot_headset_dot_rasa__service__pb2


class RasaServiceStub(object):
    """*
    This service manages the user input provided through speech and text.
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetIntent = channel.unary_unary(
                '/avikom.headset.RasaService/SetIntent',
                request_serializer=avikom_dot_headset_dot_rasa__message__pb2.RasaMessage.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetIntents = channel.unary_unary(
                '/avikom.headset.RasaService/GetIntents',
                request_serializer=avikom_dot_headset_dot_rasa__service__pb2.RasaQuery.SerializeToString,
                response_deserializer=avikom_dot_headset_dot_rasa__service__pb2.RasaResult.FromString,
                )


class RasaServiceServicer(object):
    """*
    This service manages the user input provided through speech and text.
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    def SetIntent(self, request, context):
        """/ tries to use the provided information to resolve a task step 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntents(self, request, context):
        """/ returns all intents that can be used to resolve the current task step
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RasaServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetIntent': grpc.unary_unary_rpc_method_handler(
                    servicer.SetIntent,
                    request_deserializer=avikom_dot_headset_dot_rasa__message__pb2.RasaMessage.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetIntents': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntents,
                    request_deserializer=avikom_dot_headset_dot_rasa__service__pb2.RasaQuery.FromString,
                    response_serializer=avikom_dot_headset_dot_rasa__service__pb2.RasaResult.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.headset.RasaService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RasaService(object):
    """*
    This service manages the user input provided through speech and text.
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    @staticmethod
    def SetIntent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.headset.RasaService/SetIntent',
            avikom_dot_headset_dot_rasa__message__pb2.RasaMessage.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.headset.RasaService/GetIntents',
            avikom_dot_headset_dot_rasa__service__pb2.RasaQuery.SerializeToString,
            avikom_dot_headset_dot_rasa__service__pb2.RasaResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.generic import peer_storage_service_pb2 as avikom_dot_generic_dot_peer__storage__service__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2


class PeerStorageServiceStub(object):
    """*
    Peer management service to make service ip/hostname mappings persistent over
    multiple sessions. The peer storage service is implemented in services and database.
    Only session managers should use this interface for updates and deletions. Other services
    should only access this service to retrieve information.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpdatePeer = channel.unary_unary(
                '/avikom.generic.PeerStorageService/UpdatePeer',
                request_serializer=avikom_dot_generic_dot_peer__pb2.Peer.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetPeer = channel.unary_unary(
                '/avikom.generic.PeerStorageService/GetPeer',
                request_serializer=avikom_dot_generic_dot_peer__storage__service__pb2.PeerStorageQuery.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_peer__pb2.Peer.FromString,
                )
        self.GetUserPeers = channel.unary_unary(
                '/avikom.generic.PeerStorageService/GetUserPeers',
                request_serializer=avikom_dot_generic_dot_user__pb2.User.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_peer__pb2.PeerList.FromString,
                )
        self.DeletePeer = channel.unary_unary(
                '/avikom.generic.PeerStorageService/DeletePeer',
                request_serializer=avikom_dot_generic_dot_peer__storage__service__pb2.PeerStorageQuery.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class PeerStorageServiceServicer(object):
    """*
    Peer management service to make service ip/hostname mappings persistent over
    multiple sessions. The peer storage service is implemented in services and database.
    Only session managers should use this interface for updates and deletions. Other services
    should only access this service to retrieve information.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def UpdatePeer(self, request, context):
        """/ updates peer information; requires peer.name; creates new peer if peer.name does not exist. This should not be called by peers directly! Use SessionService.RegisterUserPeer instead.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPeer(self, request, context):
        """/ returns the Peer matching the name provided in the query if peer exists
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserPeers(self, request, context):
        """/ returns list of all peers that are registered to the user_id of "User"
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePeer(self, request, context):
        """/ deletes the Peer from the database, returns error if peer not found
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PeerStorageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpdatePeer': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePeer,
                    request_deserializer=avikom_dot_generic_dot_peer__pb2.Peer.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetPeer': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPeer,
                    request_deserializer=avikom_dot_generic_dot_peer__storage__service__pb2.PeerStorageQuery.FromString,
                    response_serializer=avikom_dot_generic_dot_peer__pb2.Peer.SerializeToString,
            ),
            'GetUserPeers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserPeers,
                    request_deserializer=avikom_dot_generic_dot_user__pb2.User.FromString,
                    response_serializer=avikom_dot_generic_dot_peer__pb2.PeerList.SerializeToString,
            ),
            'DeletePeer': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePeer,
                    request_deserializer=avikom_dot_generic_dot_peer__storage__service__pb2.PeerStorageQuery.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.generic.PeerStorageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PeerStorageService(object):
    """*
    Peer management service to make service ip/hostname mappings persistent over
    multiple sessions. The peer storage service is implemented in services and database.
    Only session managers should use this interface for updates and deletions. Other services
    should only access this service to retrieve information.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def UpdatePeer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.PeerStorageService/UpdatePeer',
            avikom_dot_generic_dot_peer__pb2.Peer.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPeer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.PeerStorageService/GetPeer',
            avikom_dot_generic_dot_peer__storage__service__pb2.PeerStorageQuery.SerializeToString,
            avikom_dot_generic_dot_peer__pb2.Peer.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserPeers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.PeerStorageService/GetUserPeers',
            avikom_dot_generic_dot_user__pb2.User.SerializeToString,
            avikom_dot_generic_dot_peer__pb2.PeerList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePeer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.PeerStorageService/DeletePeer',
            avikom_dot_generic_dot_peer__storage__service__pb2.PeerStorageQuery.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/nlp/answer_question_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/nlp/answer_question_service.proto\x12\navikom.nlp\"8\n\x13\x41nswerQuestionQuery\x12\x0f\n\x07\x63ontext\x18\x01 \x01(\t\x12\x10\n\x08question\x18\x02 \x01(\t\"S\n\x16\x41nswerQuestionResponse\x12\r\n\x05score\x18\x01 \x01(\x02\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0e\n\x06\x61nswer\x18\x04 \x01(\t2p\n\x15\x41nswerQuestionService\x12W\n\x0e\x41nswerQuestion\x12\x1f.avikom.nlp.AnswerQuestionQuery\x1a\".avikom.nlp.AnswerQuestionResponse\"\x00\x42`\n\x14\x61pp.avikom.types.nlpZ5gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/nlp\xaa\x02\x10\x41vikom.Types.Nlpb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.nlp.answer_question_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024app.avikom.types.nlpZ5gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/nlp\252\002\020Avikom.Types.Nlp'
  _ANSWERQUESTIONQUERY._serialized_start=56
  _ANSWERQUESTIONQUERY._serialized_end=112
  _ANSWERQUESTIONRESPONSE._serialized_start=114
  _ANSWERQUESTIONRESPONSE._serialized_end=197
  _ANSWERQUESTIONSERVICE._serialized_start=199
  _ANSWERQUESTIONSERVICE._serialized_end=311
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.tunnel import client_to_server_pb2 as avikom_dot_tunnel_dot_client__to__server__pb2
from avikom.tunnel import server_to_client_pb2 as avikom_dot_tunnel_dot_server__to__client__pb2


class MessageTunnelServiceStub(object):
    """*
    This services allows clients behind a firewall to offer their services in the AVIKOM network.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterTunneled = channel.stream_stream(
                '/avikom.tunnel.MessageTunnelService/RegisterTunneled',
                request_serializer=avikom_dot_tunnel_dot_client__to__server__pb2.ClientToServer.SerializeToString,
                response_deserializer=avikom_dot_tunnel_dot_server__to__client__pb2.ServerToClient.FromString,
                )


class MessageTunnelServiceServicer(object):
    """*
    This services allows clients behind a firewall to offer their services in the AVIKOM network.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def RegisterTunneled(self, request_iterator, context):
        """/ Register a peer with a tunneled server connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MessageTunnelServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterTunneled': grpc.stream_stream_rpc_method_handler(
                    servicer.RegisterTunneled,
                    request_deserializer=avikom_dot_tunnel_dot_client__to__server__pb2.ClientToServer.FromString,
                    response_serializer=avikom_dot_tunnel_dot_server__to__client__pb2.ServerToClient.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.tunnel.MessageTunnelService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MessageTunnelService(object):
    """*
    This services allows clients behind a firewall to offer their services in the AVIKOM network.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def RegisterTunneled(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/avikom.tunnel.MessageTunnelService/RegisterTunneled',
            avikom_dot_tunnel_dot_client__to__server__pb2.ClientToServer.SerializeToString,
            avikom_dot_tunnel_dot_server__to__client__pb2.ServerToClient.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.instruction_media_pb2
import avikom.assistance.instruction_text_pb2
import avikom.generic.peer_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EnvironmentalFactorsUpdate(google.protobuf.message.Message):
    """*
    A message to update current environmental factors such as brightness and/or volume for a user session or a scene.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCENE_NAME_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    BRIGHTNESS_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    scene_name: builtins.str
    """/ scene/location name where data has been tracked"""
    user_id: builtins.int
    """/ when set, relates info to the current session of the user"""
    session_id: builtins.str
    """/ when set, relates info the this specific session"""
    brightness: builtins.float
    """/ environmental lightning/brightness in lumen"""
    volume: builtins.float
    """/ environmental loudness/volume in dbA"""
    def __init__(
        self,
        *,
        scene_name: builtins.str = ...,
        user_id: builtins.int = ...,
        session_id: builtins.str = ...,
        brightness: builtins.float = ...,
        volume: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["brightness", b"brightness", "scene_name", b"scene_name", "session_id", b"session_id", "user_id", b"user_id", "volume", b"volume"]) -> None: ...

global___EnvironmentalFactorsUpdate = EnvironmentalFactorsUpdate

@typing_extensions.final
class SessionEvent(google.protobuf.message.Message):
    """
    An event triggered by a peer to be escalated to the BPM engine (Camunda)
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    EVENT_NAME_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """/ session of the event"""
    event_name: builtins.str
    """/ the unique event name"""
    @property
    def sender(self) -> avikom.generic.peer_pb2.Peer:
        """/ who triggered the event"""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        event_name: builtins.str = ...,
        sender: avikom.generic.peer_pb2.Peer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sender", b"sender"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_name", b"event_name", "sender", b"sender", "session_id", b"session_id"]) -> None: ...

global___SessionEvent = SessionEvent

@typing_extensions.final
class TaskEvent(google.protobuf.message.Message):
    """
    An event that should be processed by the BPM engine (Camunda) and/or AVIKOM services.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """/ the ID of the current service task/RTS in which the event was triggered"""
    result: builtins.str
    """/ the event result/outcome; in cases of a failed task this might me an error decription"""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        result: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result", "task_id", b"task_id"]) -> None: ...

global___TaskEvent = TaskEvent

@typing_extensions.final
class InstructionList(google.protobuf.message.Message):
    """
    A list of instructions with resolved fields.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTRUCTIONS_FIELD_NUMBER: builtins.int
    MEDIA_FIELD_NUMBER: builtins.int
    @property
    def instructions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.instruction_text_pb2.InstructionText]:
        """/ textual instructions for this task step"""
    @property
    def media(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.instruction_media_pb2.InstructionMedia]:
        """/ media content for this task step; includes prefabs and world objects"""
    def __init__(
        self,
        *,
        instructions: collections.abc.Iterable[avikom.assistance.instruction_text_pb2.InstructionText] | None = ...,
        media: collections.abc.Iterable[avikom.assistance.instruction_media_pb2.InstructionMedia] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instructions", b"instructions", "media", b"media"]) -> None: ...

global___InstructionList = InstructionList



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.math import vector3d_pb2 as avikom_dot_math_dot_vector3d__pb2
from avikom.tracking import location_service_pb2 as avikom_dot_tracking_dot_location__service__pb2


class LocationServiceStub(object):
    """*
    This services provides the scene location of an object either absolute to the scene's origin or relative to another entity (e.g. the user).
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetScenePosition = channel.unary_stream(
                '/avikom.tracking.LocationService/GetScenePosition',
                request_serializer=avikom_dot_tracking_dot_location__service__pb2.TargetRequest.SerializeToString,
                response_deserializer=avikom_dot_math_dot_vector3d__pb2.Vector3D.FromString,
                )
        self.GetRelativePosition = channel.unary_stream(
                '/avikom.tracking.LocationService/GetRelativePosition',
                request_serializer=avikom_dot_tracking_dot_location__service__pb2.TargetRequest.SerializeToString,
                response_deserializer=avikom_dot_math_dot_vector3d__pb2.Vector3D.FromString,
                )


class LocationServiceServicer(object):
    """*
    This services provides the scene location of an object either absolute to the scene's origin or relative to another entity (e.g. the user).
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def GetScenePosition(self, request, context):
        """/ returns the absolute position of an object relative to the scenes origin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRelativePosition(self, request, context):
        """/ returns the  position of an object relative to the object/entity mentioned in `TargetRequest`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LocationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetScenePosition': grpc.unary_stream_rpc_method_handler(
                    servicer.GetScenePosition,
                    request_deserializer=avikom_dot_tracking_dot_location__service__pb2.TargetRequest.FromString,
                    response_serializer=avikom_dot_math_dot_vector3d__pb2.Vector3D.SerializeToString,
            ),
            'GetRelativePosition': grpc.unary_stream_rpc_method_handler(
                    servicer.GetRelativePosition,
                    request_deserializer=avikom_dot_tracking_dot_location__service__pb2.TargetRequest.FromString,
                    response_serializer=avikom_dot_math_dot_vector3d__pb2.Vector3D.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.tracking.LocationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LocationService(object):
    """*
    This services provides the scene location of an object either absolute to the scene's origin or relative to another entity (e.g. the user).
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def GetScenePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/avikom.tracking.LocationService/GetScenePosition',
            avikom_dot_tracking_dot_location__service__pb2.TargetRequest.SerializeToString,
            avikom_dot_math_dot_vector3d__pb2.Vector3D.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRelativePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/avikom.tracking.LocationService/GetRelativePosition',
            avikom_dot_tracking_dot_location__service__pb2.TargetRequest.SerializeToString,
            avikom_dot_math_dot_vector3d__pb2.Vector3D.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ImageInfo(google.protobuf.message.Message):
    """*
    This message is a header for image data transfer in chunks.
    It should always be set in the first `Image` message send to an image receiver.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    CHUNK_SIZE_FIELD_NUMBER: builtins.int
    COMPRESSED_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    size: builtins.int
    """/ size of the image in bytes"""
    chunk_size: builtins.int
    """/ transfer chunk size in bytes"""
    compressed: builtins.bool
    """/ whether the image has been compressed or send raw; NOTE: this field is not considered right now by the `ImageService`"""
    width: builtins.int
    """/ pixel width of the image"""
    height: builtins.int
    """/ pixel height of the image"""
    def __init__(
        self,
        *,
        size: builtins.int = ...,
        chunk_size: builtins.int = ...,
        compressed: builtins.bool = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk_size", b"chunk_size", "compressed", b"compressed", "height", b"height", "size", b"size", "width", b"width"]) -> None: ...

global___ImageInfo = ImageInfo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.task_pb2
import avikom.generic.user_pb2
import avikom.math.float_matrix_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SplitProcedureResult(google.protobuf.message.Message):
    """
    Results of a previously conducted split procedure, analyzed by CASPA (https://doi.org/10.3389/fpsyg.2020.597913).
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    MATRIX_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> avikom.generic.user_pb2.User:
        """/ investigated user"""
    @property
    def task(self) -> avikom.assistance.task_pb2.Task:
        """/ investigated task"""
    @property
    def matrix(self) -> avikom.math.float_matrix_pb2.FloatMatrix:
        """/ CASPA probability matrix"""
    def __init__(
        self,
        *,
        user: avikom.generic.user_pb2.User | None = ...,
        task: avikom.assistance.task_pb2.Task | None = ...,
        matrix: avikom.math.float_matrix_pb2.FloatMatrix | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["matrix", b"matrix", "task", b"task", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["matrix", b"matrix", "task", b"task", "user", b"user"]) -> None: ...

global___SplitProcedureResult = SplitProcedureResult



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/assistance_level.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/assistance/assistance_level.proto\x12\x11\x61vikom.assistance*M\n\x0f\x41ssistanceLevel\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\t\n\x05\x42RIEF\x10\x02\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x05\x12\x0b\n\x07VERBOSE\x10\tBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.assistance_level_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _ASSISTANCELEVEL._serialized_start=63
  _ASSISTANCELEVEL._serialized_end=140
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/instruction_media.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import instruction_meta_pb2 as avikom_dot_assistance_dot_instruction__meta__pb2
from avikom.assistance import instruction_media_value_pb2 as avikom_dot_assistance_dot_instruction__media__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)avikom/assistance/instruction_media.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/instruction_meta.proto\x1a/avikom/assistance/instruction_media_value.proto\"\xba\x01\n\x10InstructionMedia\x12\x30\n\x04meta\x18\x01 \x01(\x0b\x32\".avikom.assistance.InstructionMeta\x12\x39\n\x07\x63ontent\x18\x0b \x01(\x0b\x32(.avikom.assistance.InstructionMediaValue\x12\x39\n\x07preview\x18\x0c \x01(\x0b\x32(.avikom.assistance.InstructionMediaValueBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.instruction_media_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _INSTRUCTIONMEDIA._serialized_start=156
  _INSTRUCTIONMEDIA._serialized_end=342
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.assistance_level_pb2
import avikom.assistance.choices_config_pb2
import avikom.assistance.service_configuration_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TaskStereotypeCategory:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TaskStereotypeCategoryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TaskStereotypeCategory.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TASK_UNKOWN: _TaskStereotypeCategory.ValueType  # 0
    """/ default value; should not be used actively"""
    TASK_PENDING: _TaskStereotypeCategory.ValueType  # 1
    """/ waiting for user/peer to finish task, a failure needs to be raised if impossible"""
    TASK_DECISION: _TaskStereotypeCategory.ValueType  # 2
    """/ chose answer out of 'choices'"""
    TASK_ASSIGN: _TaskStereotypeCategory.ValueType  # 3
    """/ assign a 'target'"""
    TASK_GUIDE: _TaskStereotypeCategory.ValueType  # 4
    """/ guide user to a 'target'"""
    TASK_APPROVE: _TaskStereotypeCategory.ValueType  # 5
    """/ can be approved or declined, simple yes no question"""
    TASK_INPUT: _TaskStereotypeCategory.ValueType  # 6
    """/ user needs to provide further information; multiple input 'services' might be provided;"""
    TASK_INTERNAL: _TaskStereotypeCategory.ValueType  # 7
    """/ informs users/peers about ongoing processes; should not be used for critical information; might not be perceivable by the user"""

class TaskStereotypeCategory(_TaskStereotypeCategory, metaclass=_TaskStereotypeCategoryEnumTypeWrapper): ...

TASK_UNKOWN: TaskStereotypeCategory.ValueType  # 0
"""/ default value; should not be used actively"""
TASK_PENDING: TaskStereotypeCategory.ValueType  # 1
"""/ waiting for user/peer to finish task, a failure needs to be raised if impossible"""
TASK_DECISION: TaskStereotypeCategory.ValueType  # 2
"""/ chose answer out of 'choices'"""
TASK_ASSIGN: TaskStereotypeCategory.ValueType  # 3
"""/ assign a 'target'"""
TASK_GUIDE: TaskStereotypeCategory.ValueType  # 4
"""/ guide user to a 'target'"""
TASK_APPROVE: TaskStereotypeCategory.ValueType  # 5
"""/ can be approved or declined, simple yes no question"""
TASK_INPUT: TaskStereotypeCategory.ValueType  # 6
"""/ user needs to provide further information; multiple input 'services' might be provided;"""
TASK_INTERNAL: TaskStereotypeCategory.ValueType  # 7
"""/ informs users/peers about ongoing processes; should not be used for critical information; might not be perceivable by the user"""
global___TaskStereotypeCategory = TaskStereotypeCategory

@typing_extensions.final
class TaskStereotype(google.protobuf.message.Message):
    """*
    This messages classifies the assistance mechanism needed for a `TaskStep`.
    Paramaters may contain variable names in `{curly brackets}`.
    These should be resolved during runtime with the session's variable content.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORY_FIELD_NUMBER: builtins.int
    CHOICES_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    DEFAULT_ASSISTANCE_FIELD_NUMBER: builtins.int
    MINIMAL_ASSISTANCE_FIELD_NUMBER: builtins.int
    ASSISTANCE_DECREASE_FIELD_NUMBER: builtins.int
    category: global___TaskStereotypeCategory.ValueType
    """/ defines the kind of action a user can conduct to process this task"""
    @property
    def choices(self) -> avikom.assistance.choices_config_pb2.ChoicesConfig:
        """/ a set of choices a user can choose; will be only be considered for tasks where decisions have to be made"""
    target: builtins.str
    """/ the name of a  virtual or real object of central importance for that task (e.g. the target location during guidance)"""
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.service_configuration_pb2.ServiceConfiguration]:
        """/ a set of services that can be used to solve that task"""
    default_assistance: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType
    """/ the default assistance for this step if no step proficiency is available"""
    minimal_assistance: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType
    """/ overrides the category-induced minimal assistance levels but cannot be lower"""
    assistance_decrease: builtins.float
    """/ factor to reduce `tendency` when a task was conducted successfully, this will be combined with user preferences; 0 is considered unset and will be ignored"""
    def __init__(
        self,
        *,
        category: global___TaskStereotypeCategory.ValueType = ...,
        choices: avikom.assistance.choices_config_pb2.ChoicesConfig | None = ...,
        target: builtins.str = ...,
        services: collections.abc.Iterable[avikom.assistance.service_configuration_pb2.ServiceConfiguration] | None = ...,
        default_assistance: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType = ...,
        minimal_assistance: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType = ...,
        assistance_decrease: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["choices", b"choices"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assistance_decrease", b"assistance_decrease", "category", b"category", "choices", b"choices", "default_assistance", b"default_assistance", "minimal_assistance", b"minimal_assistance", "services", b"services", "target", b"target"]) -> None: ...

global___TaskStereotype = TaskStereotype



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.generic.peer_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ClientToServer(google.protobuf.message.Message):
    """*
    A message to be sent from a tunneled client to the server that (will) receive messages
    meant for this client. The first message should contain peer information and ByteString
    responses afterwards.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    PEER_FIELD_NUMBER: builtins.int
    response: builtins.bytes
    """/ A response to a RPC processed by the client"""
    message_id: builtins.int
    """/ The ID of the call related to the response"""
    @property
    def peer(self) -> avikom.generic.peer_pb2.Peer:
        """/ Client information sent as the first message to the server"""
    def __init__(
        self,
        *,
        response: builtins.bytes = ...,
        message_id: builtins.int = ...,
        peer: avikom.generic.peer_pb2.Peer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["peer", b"peer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_id", b"message_id", "peer", b"peer", "response", b"response"]) -> None: ...

global___ClientToServer = ClientToServer



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SystemEvent:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SystemEventEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SystemEvent.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EVENT_UNKNOWN: _SystemEvent.ValueType  # 0
    """/ Unknown event and default value. Should not actively be used."""
    EVENT_TASK_DONE: _SystemEvent.ValueType  # 1
    """/ Current RuntimeTask should be considered done; It is recommended to use  `SessionService.CompleteTaskStep` where possible."""
    EVENT_TASK_FAILED: _SystemEvent.ValueType  # 2
    """/ Current RuntimeTask should be considered failed; It is recommended to use  `SessionService.FailTaskStep` where possible."""

class SystemEvent(_SystemEvent, metaclass=_SystemEventEnumTypeWrapper):
    """*
    An enum representing an event hat has been triggered by some (parallel) activity of the system.
    Event handling should be done by a SessionService and should be converted into a string beforehand.
    Note that custom and task-specific events are defined as strings right away. This enum shall only be used for 
    reoccuring task-independent events.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

EVENT_UNKNOWN: SystemEvent.ValueType  # 0
"""/ Unknown event and default value. Should not actively be used."""
EVENT_TASK_DONE: SystemEvent.ValueType  # 1
"""/ Current RuntimeTask should be considered done; It is recommended to use  `SessionService.CompleteTaskStep` where possible."""
EVENT_TASK_FAILED: SystemEvent.ValueType  # 2
"""/ Current RuntimeTask should be considered failed; It is recommended to use  `SessionService.FailTaskStep` where possible."""
global___SystemEvent = SystemEvent



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/session_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import assistance_level_pb2 as avikom_dot_assistance_dot_assistance__level__pb2
from avikom.assistance import instruction_text_pb2 as avikom_dot_assistance_dot_instruction__text__pb2
from avikom.assistance import instruction_media_pb2 as avikom_dot_assistance_dot_instruction__media__pb2
from avikom.assistance import runtime_step_list_pb2 as avikom_dot_assistance_dot_runtime__step__list__pb2
from avikom.assistance import session_pb2 as avikom_dot_assistance_dot_session__pb2
from avikom.assistance import session_query_pb2 as avikom_dot_assistance_dot_session__query__pb2
from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.generic import modality_pb2 as avikom_dot_generic_dot_modality__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'avikom/assistance/session_service.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/assistance_level.proto\x1a(avikom/assistance/instruction_text.proto\x1a)avikom/assistance/instruction_media.proto\x1a)avikom/assistance/runtime_step_list.proto\x1a\x1f\x61vikom/assistance/session.proto\x1a%avikom/assistance/session_query.proto\x1a\x1c\x61vikom/options/options.proto\x1a\x1d\x61vikom/generic/modality.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x19\x61vikom/generic/peer.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"y\n\x1a\x45nvironmentalFactorsUpdate\x12\x12\n\nscene_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x12\n\nbrightness\x18\x05 \x01(\x02\x12\x0e\n\x06volume\x18\x06 \x01(\x02\"\\\n\x0cSessionEvent\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nevent_name\x18\x02 \x01(\t\x12$\n\x06sender\x18\x03 \x01(\x0b\x32\x14.avikom.generic.Peer\",\n\tTaskEvent\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\t\"\x7f\n\x0fInstructionList\x12\x38\n\x0cinstructions\x18\x01 \x03(\x0b\x32\".avikom.assistance.InstructionText\x12\x32\n\x05media\x18\x02 \x03(\x0b\x32#.avikom.assistance.InstructionMedia2\xa2\x06\n\x0eSessionService\x12\x46\n\tEmitEvent\x12\x1f.avikom.assistance.SessionEvent\x1a\x16.avikom.generic.Result\"\x00\x12J\n\x10\x43ompleteTaskStep\x12\x1c.avikom.assistance.TaskEvent\x1a\x16.avikom.generic.Result\"\x00\x12\x46\n\x0c\x46\x61ilTaskStep\x12\x1c.avikom.assistance.TaskEvent\x1a\x16.avikom.generic.Result\"\x00\x12W\n\x0eGetCurrentStep\x12\x1f.avikom.assistance.SessionQuery\x1a\".avikom.assistance.RuntimeStepList\"\x00\x12I\n\x0cStartSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x16.avikom.generic.Result\"\x00\x12K\n\x0eSuspendSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x16.avikom.generic.Result\"\x00\x12G\n\nEndSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x16.avikom.generic.Result\"\x00\x12\x65\n\x1aUpdateEnvironmentalFactors\x12-.avikom.assistance.EnvironmentalFactorsUpdate\x1a\x16.avikom.generic.Result\"\x00\x12N\n\x10RegisterUserPeer\x12\x14.avikom.generic.Peer\x1a\".avikom.assistance.RuntimeStepList\"\x00\x12\x43\n\x0f\x45ndAllProcesses\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.session_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _ENVIRONMENTALFACTORSUPDATE._serialized_start=480
  _ENVIRONMENTALFACTORSUPDATE._serialized_end=601
  _SESSIONEVENT._serialized_start=603
  _SESSIONEVENT._serialized_end=695
  _TASKEVENT._serialized_start=697
  _TASKEVENT._serialized_end=741
  _INSTRUCTIONLIST._serialized_start=743
  _INSTRUCTIONLIST._serialized_end=870
  _SESSIONSERVICE._serialized_start=873
  _SESSIONSERVICE._serialized_end=1675
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/session.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.assistance import runtime_task_step_pb2 as avikom_dot_assistance_dot_runtime__task__step__pb2
from avikom.camunda import external_task_pb2 as avikom_dot_camunda_dot_external__task__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.generic import user_profile_pb2 as avikom_dot_generic_dot_user__profile__pb2
from avikom.generic import modality_pb2 as avikom_dot_generic_dot_modality__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61vikom/assistance/session.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\x1d\x61vikom/assistance/scene.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a)avikom/assistance/runtime_task_step.proto\x1a\"avikom/camunda/external_task.proto\x1a\x19\x61vikom/generic/peer.proto\x1a!avikom/generic/user_profile.proto\x1a\x1d\x61vikom/generic/modality.proto\"\xc0\x02\n\x07Session\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12\'\n\x05scene\x18\x02 \x01(\x0b\x32\x18.avikom.assistance.Scene\x12#\n\x05peers\x18\x03 \x03(\x0b\x32\x14.avikom.generic.Peer\x12\x33\n\x07\x63urrent\x18\x04 \x03(\x0b\x32\".avikom.assistance.RuntimeTaskStep\x12,\n\x07profile\x18\x05 \x01(\x0b\x32\x1b.avikom.generic.UserProfile\x12%\n\x04task\x18\x06 \x01(\x0b\x32\x17.avikom.assistance.Task\x12\x30\n\x0emodal_affinity\x18\x07 \x01(\x0b\x32\x18.avikom.generic.Modality\x12\x11\n\tjson_data\x18\n \x01(\t:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.session_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SESSION.fields_by_name['id']._options = None
  _SESSION.fields_by_name['id']._serialized_options = b'\212\265\030\002\020\001'
  _SESSION._options = None
  _SESSION._serialized_options = b'\210\265\030\001'
  _SESSION._serialized_start=318
  _SESSION._serialized_end=638
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/glasses/media_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import content_type_pb2 as avikom_dot_generic_dot_content__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61vikom/glasses/media_info.proto\x12\x0e\x61vikom.glasses\x1a!avikom/generic/content_type.proto\"h\n\tMediaInfo\x12\x12\n\nmedia_name\x18\x01 \x01(\t\x12\x31\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x1b.avikom.generic.ContentType\x12\x14\n\x0cmilliseconds\x18\x03 \x01(\rBl\n\x18\x61pp.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\xaa\x02\x14\x41vikom.Types.Glassesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.glasses.media_info_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\252\002\024Avikom.Types.Glasses'
  _MEDIAINFO._serialized_start=86
  _MEDIAINFO._serialized_end=190
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/glasses/remote_control_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+avikom/glasses/remote_control_service.proto\x12\x0e\x61vikom.glasses\x1a\x1b\x61vikom/generic/result.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto2\xf0\x04\n\x14RemoteControlService\x12\x43\n\x0fShowStepBrowser\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12\x43\n\x0fHideStepBrowser\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12@\n\x0cShowNextStep\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12\x44\n\x10ShowPreviousStep\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12\x41\n\rShowNextMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12\x45\n\x11ShowPreviousMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12=\n\tPlayMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12>\n\nPauseMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12=\n\tStopMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x42l\n\x18\x61pp.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\xaa\x02\x14\x41vikom.Types.Glassesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.glasses.remote_control_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\252\002\024Avikom.Types.Glasses'
  _REMOTECONTROLSERVICE._serialized_start=152
  _REMOTECONTROLSERVICE._serialized_end=776
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61vikom/generic/user.proto\x12\x0e\x61vikom.generic\x1a\x1c\x61vikom/options/options.proto\"Z\n\x04User\x12\x12\n\nfirst_name\x18\x01 \x01(\t\x12\x11\n\tlast_name\x18\x02 \x01(\t\x12\x12\n\x02id\x18\x03 \x01(\x04\x42\x06\x8a\xb5\x18\x02\x10\x01\x12\x11\n\tusernames\x18\x04 \x03(\t:\x04\x88\xb5\x18\x01\x42l\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _USER.fields_by_name['id']._options = None
  _USER.fields_by_name['id']._serialized_options = b'\212\265\030\002\020\001'
  _USER._options = None
  _USER._serialized_options = b'\210\265\030\001'
  _USER._serialized_start=75
  _USER._serialized_end=165
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FieldOptions(google.protobuf.message.Message):
    """*
    This is a meta message which is not supposed to be shared but used to define database-related properties.
    These properties will be evaluated by the protoc converter plugins to determine -- for instance -- the mongoDB schema required to store and retrieve a decorated message.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    UNIQUE_FIELD_NUMBER: builtins.int
    DEFAULT_FIELD_NUMBER: builtins.int
    MATCH_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    IMMUTABLE_FIELD_NUMBER: builtins.int
    AUTO_INDEX_FIELD_NUMBER: builtins.int
    index: builtins.bool
    """/ marks the field as index; NOTE: unused; use 'unique' instead"""
    unique: builtins.bool
    """/ interprete field as key for the schema; will generate approriate helper functions to retrieve documents"""
    default: builtins.str
    """/ define default value for an (optional) field"""
    match: builtins.str
    """/ regex for data validation; NOTE: unused"""
    min: builtins.str
    """/ minimal value for a field; NOTE: unused"""
    immutable: builtins.bool
    """/ mark a field as unchangeable; NOTE: unused"""
    auto_index: builtins.bool
    """/ increase the index automatically; NOTE: unused"""
    def __init__(
        self,
        *,
        index: builtins.bool = ...,
        unique: builtins.bool = ...,
        default: builtins.str = ...,
        match: builtins.str = ...,
        min: builtins.str = ...,
        immutable: builtins.bool = ...,
        auto_index: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_index", b"auto_index", "default", b"default", "immutable", b"immutable", "index", b"index", "match", b"match", "min", b"min", "unique", b"unique"]) -> None: ...

global___FieldOptions = FieldOptions

SCHEMA_FIELD_NUMBER: builtins.int
SCHEMA_DEFINITION_FIELD_NUMBER: builtins.int
schema: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, global___FieldOptions]
schema_definition: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.runtime_step_state_pb2
import avikom.assistance.task_step_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RuntimeTaskStep(google.protobuf.message.Message):
    """*
    Adds runtime-specific (temporal) data to a (static) TaskStep
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEP_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def step(self) -> avikom.assistance.task_step_pb2.TaskStep:
        """/ the task defintion; fields have been dynamically altered and contain context-specific values"""
    id: builtins.str
    """/ a unique key to define this particular RTS instance"""
    state: avikom.assistance.runtime_step_state_pb2.RuntimeStepState.ValueType
    """/ current state of the runtime task step"""
    def __init__(
        self,
        *,
        step: avikom.assistance.task_step_pb2.TaskStep | None = ...,
        id: builtins.str = ...,
        state: avikom.assistance.runtime_step_state_pb2.RuntimeStepState.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["step", b"step"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "state", b"state", "step", b"step"]) -> None: ...

global___RuntimeTaskStep = RuntimeTaskStep



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/session_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%avikom/assistance/session_query.proto\x12\x11\x61vikom.assistance\"d\n\x0cSessionQuery\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\x12\x12\n\nscene_name\x18\x03 \x01(\t\x12\x11\n\ttask_name\x18\x04 \x01(\t\x12\x10\n\x08username\x18\x05 \x01(\tBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.session_query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SESSIONQUERY._serialized_start=60
  _SESSIONQUERY._serialized_end=160
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import logger_service_pb2 as avikom_dot_generic_dot_logger__service__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2


class LoggerServiceStub(object):
    """
    This service receives debug messages and handles them. 
    Currently not in use.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Log = channel.unary_unary(
                '/avikom.generic.LoggerService/Log',
                request_serializer=avikom_dot_generic_dot_logger__service__pb2.Message.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class LoggerServiceServicer(object):
    """
    This service receives debug messages and handles them. 
    Currently not in use.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def Log(self, request, context):
        """/ Logs a certain message and displays it in the console
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LoggerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Log': grpc.unary_unary_rpc_method_handler(
                    servicer.Log,
                    request_deserializer=avikom_dot_generic_dot_logger__service__pb2.Message.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.generic.LoggerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LoggerService(object):
    """
    This service receives debug messages and handles them. 
    Currently not in use.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def Log(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.LoggerService/Log',
            avikom_dot_generic_dot_logger__service__pb2.Message.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/rpc_endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/generic/rpc_endpoint.proto\x12\x0e\x61vikom.generic*\xbc\x02\n\x0bRpcEndpoint\x12\x14\n\x10\x45NDPOINT_UNKNOWN\x10\x00\x12\x1b\n\x17\x45NDPOINT_SCENE_CONSUMER\x10\x01\x12\x1b\n\x17\x45NDPOINT_MEDIA_FOLLOWER\x10\x02\x12\x1b\n\x17\x45NDPOINT_REMOTE_CONTROL\x10\x03\x12\x1f\n\x1b\x45NDPOINT_AUDIO_PEER_CONTROL\x10\x04\x12\x11\n\rENDPOINT_GAZE\x10\x05\x12\x12\n\x0e\x45NDPOINT_IMAGE\x10\x06\x12\x15\n\x11\x45NDPOINT_LOCATION\x10\x07\x12\x1e\n\x1a\x45NDPOINT_INTERACTION_EVENT\x10\x08\x12\x1d\n\x19\x45NDPOINT_SERVICE_PROVIDER\x10\t\x12\"\n\x1e\x45NDPOINT_RUNTIME_STEP_CONSUMER\x10\nBl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.rpc_endpoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _RPCENDPOINT._serialized_start=54
  _RPCENDPOINT._serialized_end=370
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.headset.common_utterance_pb2
import avikom.headset.functional_sound_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Mode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Mode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MODE_UNKNOWN: _Mode.ValueType  # 0
    """/ represents an unset mode; should not be used actively"""
    MODE_DEFAULT: _Mode.ValueType  # 1
    """/ resets the auditory peer to plain input-output mode"""
    MODE_TRANSPARENT: _Mode.ValueType  # 2
    """/ sound picked up be the microphone is played back via the headphones"""

class Mode(_Mode, metaclass=_ModeEnumTypeWrapper):
    """*
    Defines the mode that should be activated for the auditory peer. The mode changes the auditory input and output 
    behaviour of the auditory peer.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

MODE_UNKNOWN: Mode.ValueType  # 0
"""/ represents an unset mode; should not be used actively"""
MODE_DEFAULT: Mode.ValueType  # 1
"""/ resets the auditory peer to plain input-output mode"""
MODE_TRANSPARENT: Mode.ValueType  # 2
"""/ sound picked up be the microphone is played back via the headphones"""
global___Mode = Mode

@typing_extensions.final
class AudioPeerModeRequest(google.protobuf.message.Message):
    """*
    A Mode request passed to SetMode.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODE_FIELD_NUMBER: builtins.int
    mode: global___Mode.ValueType
    """/ the mode the auditory peer should activate"""
    def __init__(
        self,
        *,
        mode: global___Mode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode"]) -> None: ...

global___AudioPeerModeRequest = AudioPeerModeRequest

@typing_extensions.final
class FunctionalSoundRequest(google.protobuf.message.Message):
    """*
    A FunctionalSound request that either includes a standardized functional sound or the name of 
    an audio file to be played. The audio file has to be available in the web-client data path "data/Default/Sounds".
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTIONAL_SOUND_FIELD_NUMBER: builtins.int
    OTHER_SOUND_FIELD_NUMBER: builtins.int
    functional_sound: avikom.headset.functional_sound_pb2.FunctionalSound.ValueType
    """/ a set of predefined sounds to provide feedback to users"""
    other_sound: builtins.str
    """/"""
    def __init__(
        self,
        *,
        functional_sound: avikom.headset.functional_sound_pb2.FunctionalSound.ValueType = ...,
        other_sound: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["functional_sound", b"functional_sound", "other_sound", b"other_sound"]) -> None: ...

global___FunctionalSoundRequest = FunctionalSoundRequest

@typing_extensions.final
class SayRequest(google.protobuf.message.Message):
    """*
    A request that either includes a standardized utterance or custom output to be played back via TTS. 
    The output is queued with other speech output.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UTTERANCE_FIELD_NUMBER: builtins.int
    COMMON_UTTERANCE_FIELD_NUMBER: builtins.int
    utterance: builtins.str
    """/ a string representation of what should be generated as speech"""
    common_utterance: avikom.headset.common_utterance_pb2.CommonUtterance.ValueType
    """/ a set of predefined speech outputs"""
    def __init__(
        self,
        *,
        utterance: builtins.str = ...,
        common_utterance: avikom.headset.common_utterance_pb2.CommonUtterance.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_utterance", b"common_utterance", "utterance", b"utterance"]) -> None: ...

global___SayRequest = SayRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.service_configuration_pb2
import avikom.generic.peer_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServiceRequest(google.protobuf.message.Message):
    """*
    A request passed to `ServiceProviderService`.
    @author Alexander McService Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    PEERS_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """/ represents the task that is related to the service request"""
    @property
    def configuration(self) -> avikom.assistance.service_configuration_pb2.ServiceConfiguration:
        """/ service type and configuration parameters"""
    @property
    def peers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.peer_pb2.Peer]:
        """/ a list of available peers that can be used to resolve the service request"""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        configuration: avikom.assistance.service_configuration_pb2.ServiceConfiguration | None = ...,
        peers: collections.abc.Iterable[avikom.generic.peer_pb2.Peer] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "peers", b"peers", "task_id", b"task_id"]) -> None: ...

global___ServiceRequest = ServiceRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.camunda.variable_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ExternalTask(google.protobuf.message.Message):
    """*
    A storable representation of an external task published by the BPM engine (Camunda).
    The field description has been derived from the official REST-API documentation.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_INSTANCE_ID_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    EXECUTION_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCK_EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    PROCESS_DEFINITION_ID_FIELD_NUMBER: builtins.int
    PROCESS_DEFINITION_KEY_FIELD_NUMBER: builtins.int
    PROCESS_INSTANCE_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    RETRIES_FIELD_NUMBER: builtins.int
    WORKER_ID_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    activity_id: builtins.str
    """/ id of the activity that this external task belongs to"""
    activity_instance_id: builtins.str
    """/ id of the activity instance that the external task belongs to"""
    error_message: builtins.str
    """/ error message that was supplied when the last failure of this task was reported"""
    execution_id: builtins.str
    """/ id of the execution that the external task belongs to"""
    id: builtins.str
    """/ external task's id"""
    lock_expiration_time: builtins.str
    """/ date that the task's most recent lock expires or has expired"""
    process_definition_id: builtins.str
    """/ id of the process definition the external task is defined in"""
    process_definition_key: builtins.str
    """/ key of the process definition the external task is defined in"""
    process_instance_id: builtins.str
    """/ id of the process instance the external task belongs to"""
    tenant_id: builtins.str
    """/ id of the tenant the external task belongs to"""
    retries: builtins.int
    """/ number of retries the task currently has left"""
    worker_id: builtins.str
    """/ id of the worker that posesses or posessed the most recent lock"""
    priority: builtins.int
    """/ priority of the external task"""
    topic_name: builtins.str
    """/ external task's topic name"""
    @property
    def variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.camunda.variable_pb2.Variable]:
        """/ a set of local and global variables passed to the external service"""
    def __init__(
        self,
        *,
        activity_id: builtins.str = ...,
        activity_instance_id: builtins.str = ...,
        error_message: builtins.str = ...,
        execution_id: builtins.str = ...,
        id: builtins.str = ...,
        lock_expiration_time: builtins.str = ...,
        process_definition_id: builtins.str = ...,
        process_definition_key: builtins.str = ...,
        process_instance_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
        retries: builtins.int = ...,
        worker_id: builtins.str = ...,
        priority: builtins.int = ...,
        topic_name: builtins.str = ...,
        variables: collections.abc.Iterable[avikom.camunda.variable_pb2.Variable] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "activity_instance_id", b"activity_instance_id", "error_message", b"error_message", "execution_id", b"execution_id", "id", b"id", "lock_expiration_time", b"lock_expiration_time", "priority", b"priority", "process_definition_id", b"process_definition_id", "process_definition_key", b"process_definition_key", "process_instance_id", b"process_instance_id", "retries", b"retries", "tenant_id", b"tenant_id", "topic_name", b"topic_name", "variables", b"variables", "worker_id", b"worker_id"]) -> None: ...

global___ExternalTask = ExternalTask



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/waypoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.math import vector3d_pb2 as avikom_dot_math_dot_vector3d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61vikom/unity/waypoint.proto\x12\x0c\x61vikom.unity\x1a\x1a\x61vikom/math/vector3d.proto\"g\n\x08Waypoint\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\x08location\x18\x02 \x01(\x0b\x32\x15.avikom.math.Vector3D\x12\x11\n\tneighbors\x18\x03 \x03(\t\x12\x11\n\tthreshold\x18\x04 \x01(\x02\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.waypoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _WAYPOINT._serialized_start=73
  _WAYPOINT._serialized_end=176
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/common_utterance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%avikom/headset/common_utterance.proto\x12\x0e\x61vikom.headset*\x8b\x01\n\x0f\x43ommonUtterance\x12\x1c\n\x18\x43OMMON_UTTERANCE_DEFAULT\x10\x00\x12\x1b\n\x17\x43OMMON_UTTERANCE_REPEAT\x10\x01\x12\x1c\n\x18\x43OMMON_UTTERANCE_APPROVE\x10\x02\x12\x1f\n\x1b\x43OMMON_UTTERANCE_COMPLIMENT\x10\x03\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.common_utterance_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _COMMONUTTERANCE._serialized_start=58
  _COMMONUTTERANCE._serialized_end=197
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.assistance import session_pb2 as avikom_dot_assistance_dot_session__pb2
from avikom.assistance import session_query_pb2 as avikom_dot_assistance_dot_session__query__pb2
from avikom.assistance import session_storage_service_pb2 as avikom_dot_assistance_dot_session__storage__service__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class SessionStorageServiceStub(object):
    """*
    A service to store, alter and retrieve sessions.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SaveSession = channel.unary_unary(
                '/avikom.assistance.SessionStorageService/SaveSession',
                request_serializer=avikom_dot_assistance_dot_session__pb2.Session.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetSession = channel.unary_unary(
                '/avikom.assistance.SessionStorageService/GetSession',
                request_serializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_session__pb2.Session.FromString,
                )
        self.GetAllSessions = channel.unary_unary(
                '/avikom.assistance.SessionStorageService/GetAllSessions',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_session__storage__service__pb2.SessionList.FromString,
                )
        self.DeleteSession = channel.unary_unary(
                '/avikom.assistance.SessionStorageService/DeleteSession',
                request_serializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class SessionStorageServiceServicer(object):
    """*
    A service to store, alter and retrieve sessions.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def SaveSession(self, request, context):
        """/ stores a sesion; if it exists it will be updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSession(self, request, context):
        """/ retrieves a single session; `SessionQuery` must return a single session
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllSessions(self, request, context):
        """/ returns all currently stored sessions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSession(self, request, context):
        """/ deletes (a) session(s); deletes all sessions that fulfill `SessionQuery`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SessionStorageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SaveSession': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveSession,
                    request_deserializer=avikom_dot_assistance_dot_session__pb2.Session.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSession,
                    request_deserializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.FromString,
                    response_serializer=avikom_dot_assistance_dot_session__pb2.Session.SerializeToString,
            ),
            'GetAllSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllSessions,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_assistance_dot_session__storage__service__pb2.SessionList.SerializeToString,
            ),
            'DeleteSession': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSession,
                    request_deserializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.assistance.SessionStorageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SessionStorageService(object):
    """*
    A service to store, alter and retrieve sessions.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def SaveSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionStorageService/SaveSession',
            avikom_dot_assistance_dot_session__pb2.Session.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionStorageService/GetSession',
            avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
            avikom_dot_assistance_dot_session__pb2.Session.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionStorageService/GetAllSessions',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_assistance_dot_session__storage__service__pb2.SessionList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionStorageService/DeleteSession',
            avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/runtime_step_consumer_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.assistance import runtime_step_list_pb2 as avikom_dot_assistance_dot_runtime__step__list__pb2
from avikom.assistance import runtime_step_state_pb2 as avikom_dot_assistance_dot_runtime__step__state__pb2
from avikom.assistance import runtime_step_state_change_pb2 as avikom_dot_assistance_dot_runtime__step__state__change__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5avikom/assistance/runtime_step_consumer_service.proto\x12\x11\x61vikom.assistance\x1a\x19\x61vikom/generic/peer.proto\x1a)avikom/assistance/runtime_step_list.proto\x1a*avikom/assistance/runtime_step_state.proto\x1a\x31\x61vikom/assistance/runtime_step_state_change.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1bgoogle/protobuf/empty.proto2\x87\x02\n\x1aRuntimeStepConsumerService\x12O\n\x0fSetRuntimeSteps\x12\".avikom.assistance.RuntimeStepList\x1a\x16.avikom.generic.Result\"\x00\x12X\n\x11UpdateRuntimeStep\x12).avikom.assistance.RuntimeStepStateChange\x1a\x16.google.protobuf.Empty\"\x00\x12>\n\x08SetPeers\x12\x18.avikom.generic.PeerList\x1a\x16.avikom.generic.Result\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.runtime_step_consumer_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _RUNTIMESTEPCONSUMERSERVICE._serialized_start=300
  _RUNTIMESTEPCONSUMERSERVICE._serialized_end=563
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.scene_pb2
import avikom.assistance.task_pb2
import avikom.assistance.task_step_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TaskStorageQuery(google.protobuf.message.Message):
    """*
    A query to retrieve a scene, task or task step via its name.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ name of a scene, task or task step"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___TaskStorageQuery = TaskStorageQuery

@typing_extensions.final
class SceneList(google.protobuf.message.Message):
    """*
    A list of scenes.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCENES_FIELD_NUMBER: builtins.int
    @property
    def scenes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.scene_pb2.Scene]:
        """a scene list"""
    def __init__(
        self,
        *,
        scenes: collections.abc.Iterable[avikom.assistance.scene_pb2.Scene] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scenes", b"scenes"]) -> None: ...

global___SceneList = SceneList

@typing_extensions.final
class TaskList(google.protobuf.message.Message):
    """*
    A list of tasks.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASKS_FIELD_NUMBER: builtins.int
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.task_pb2.Task]:
        """a task list"""
    def __init__(
        self,
        *,
        tasks: collections.abc.Iterable[avikom.assistance.task_pb2.Task] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tasks", b"tasks"]) -> None: ...

global___TaskList = TaskList

@typing_extensions.final
class TaskStepList(google.protobuf.message.Message):
    """*
    A list of task steps.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEPS_FIELD_NUMBER: builtins.int
    @property
    def steps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.task_step_pb2.TaskStep]:
        """a task step list"""
    def __init__(
        self,
        *,
        steps: collections.abc.Iterable[avikom.assistance.task_step_pb2.TaskStep] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["steps", b"steps"]) -> None: ...

global___TaskStepList = TaskStepList
